function [ff,lab,f] = getfeature(b,show)
% Extract features from handwritten digit data.
%    [ff,lab,f] = getfeature(b,show)
%
%    Inputs:
%        b    ... digit data (a cell array)
%        show ... set to 1 to see a plot (default = 0)
%    Outputs:
%        ff   ... features returned in a matrix
%        lab  ... corresponding labels
%        f    ... features returned in the same structure as b (a cell array)
%
%    to see how the features look like, try:
%
%          load chars;
%          getfeature(b{1}{1},1);
%          getfeature(b{2}{1},1);
%          etc.
%    

if nargin < 2, show = 0; end;
if ~iscell(b), bb{1}{1} = b; b = bb; clear bb; end; 

da = 15*pi/180;
angles = [0:45:360-45]'*pi/180;

kk = 0;
for ii = 1 : length(b),
   for jj = 1 : length(b{ii}),
      
        a = b{ii}{jj};
		a = normalizesize(centralize(a));

		a = a - ones(size(a(:,1)))*min(a);
		aa = a(:,1)'*a(:,2)./fliplr(sum(a));
		a = a - ones(size(a(:,1)))*aa;

		[th,r] = cart2pol(a(:,1),a(:,2));
		r = r/1000;
		ind = find(th<0);
		th(ind) = 2*pi + th(ind);

        if show, polar(th,r,'.'); hold on; end;
		for i = 1 : length(angles),
		    ind = find((th > angles(i)) & (th < angles(i)+da));
		    if ~isempty(ind),
		        F(i,1) = min(r(ind));
		        F(i,2) = max(r(ind));
		    else
		        F(i,1) = 0;
		        F(i,2) = 0;
		    end;    
            if show, 
                h = polar([angles(i) angles(i)],[0 F(i,1)],'r'); set(h,'linewidth',2);
    		    h = polar([angles(i) angles(i)],[F(i,1) F(i,1)+F(i,2)],'g'); set(h,'linewidth',2);
            end;    
		end;
        kk = kk + 1;
        ff(:,kk) = F(:);
        lab(kk) = ii;
        f{ii}{jj} = F(:);
		if show, hold off; end;
   end;
end;